@@ -2,7 +2,8 @@
 #'
 #' 
 #' @param file_paths a vactor of paths to image file(s) for which you want tags
-#' 
+#' @param \dots Additional arguments passed to \code{\link{clarifai_POST}}.
+#'  
 #' @return Named list of length 3: \code{status_code}, \code{status_msg}, and \code{results}. 
 #' \code{results} is a named list of length 12. Contains information about max. and 
 #' min. image and video size allowed etc. 
@@ -16,22 +17,16 @@
 #' get_color(file_paths="path_to_image")
 #' }
 
-get_color <- function(file_paths=NULL) {
+get_color <- function(file_paths=NULL, ...) {
 
 	clarifai_check_token()
         
-    if (! all(file.exists(file_paths))) stop("File Doesn't Exist. Please check the path.")
+    if (! all(file.exists(file_paths))) stop("One or more of the files don't exist. Please check the path.", call. = FALSE)
 
-    paths <- lapply(file_paths, form_file)
-    names(paths) <- rep("encoded_image", length(paths))
+    query <- lapply(file_paths, form_file)
+    names(query) <- rep("encoded_image", length(query))
 
-    h <- new_handle()
-	handle_setopt(h,  customrequest = "POST")
-	handle_setheaders(h, "Authorization" = paste0("Bearer ", Sys.getenv("ClarifaiToken")))
-	handle_setform(h, .list=paths)
-
-	color_con    <- curl_fetch_memory("https://api.clarifai.com/v1/color/", handle=h)
-	color        <- fromJSON(rawToChar(color_con$content))
+	color <- clarifai_POST(path="color/", query, ...)
 
 	return(invisible(color))
 
