@@ -1,6 +1,9 @@
 #' List all the languages that the tag API call supports
 #'
 #'
+#' @param \dots Additional arguments passed to \code{\link{clarifai_GET}}.
+#' 
+#' 
 #' @return character vector listing all the languages that tag API call supports. See \code{\link{tag_images}} and code{\link{tag_image_urls}}
 #' 
 #' @export
@@ -9,15 +12,11 @@
 #' get_langs()
 #' }
 
-get_langs <- function() {
+get_langs <- function(...) {
 
 	clarifai_check_token()
-		
-    h <- new_handle()
-	handle_setopt(h,  customrequest = "GET")
-	handle_setheaders(h, "Authorization" = paste0("Bearer ", Sys.getenv("ClarifaiToken")))
-	info_con   <- curl_fetch_memory("https://api.clarifai.com/v1/info/languages/", handle=h)
-	info       <- fromJSON(rawToChar(info_con$content))
+	
+	info <- clarifai_GET(path="info/languages/", query=NULL, ...)
 
 	langs <- unname(unlist(info[grepl("languages", names(info))]))
 
